@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
 #
 # Copyright 2004-2006 Zuza Software Foundation
 #
@@ -23,25 +21,32 @@
 """
 
 import os.path
-import six
 from io import BytesIO
 
 from translate.misc import optrecurse
 
-
 # Don't import optparse ourselves, get the version from optrecurse.
 optparse = optrecurse.optparse
 
 
-class ConvertOptionParser(optrecurse.RecursiveOptionParser, object):
+class ConvertOptionParser(optrecurse.RecursiveOptionParser):
     """A specialized Option Parser for convertor tools..."""
 
-    def __init__(self, formats, usetemplates=False, usepots=False,
-                 allowmissingtemplate=False, description=None):
+    def __init__(
+        self,
+        formats,
+        usetemplates=False,
+        usepots=False,
+        allowmissingtemplate=False,
+        description=None,
+    ):
         """construct the specialized Option Parser"""
-        optrecurse.RecursiveOptionParser.__init__(self, formats, usetemplates,
-                                                  allowmissingtemplate=allowmissingtemplate,
-                                                  description=description)
+        super().__init__(
+            formats,
+            usetemplates,
+            allowmissingtemplate=allowmissingtemplate,
+            description=description,
+        )
         self.usepots = usepots
         self.settimestampoption()
         self.setpotoption()
@@ -55,62 +60,92 @@ class ConvertOptionParser(optrecurse.RecursiveOptionParser, object):
             fuzzyhelp += " (default)"
         else:
             nofuzzyhelp += " (default)"
-        self.add_option("", "--fuzzy", dest="includefuzzy",
-                        action="store_true", default=default, help=fuzzyhelp)
-        self.add_option("", "--nofuzzy", dest="includefuzzy",
-                        action="store_false", default=default, help=nofuzzyhelp)
+        self.add_option(
+            "",
+            "--fuzzy",
+            dest="includefuzzy",
+            action="store_true",
+            default=default,
+            help=fuzzyhelp,
+        )
+        self.add_option(
+            "",
+            "--nofuzzy",
+            dest="includefuzzy",
+            action="store_false",
+            default=default,
+            help=nofuzzyhelp,
+        )
         self.passthrough.append("includefuzzy")
 
     def add_remove_untranslated_option(self, default=False):
         """Adds an option to remove key value from output if it is
         untranslated.
         """
-        self.add_option("", "--removeuntranslated", dest="remove_untranslated",
-                        default=False, action="store_true",
-                        help="remove untranslated strings from output")
+        self.add_option(
+            "",
+            "--removeuntranslated",
+            dest="remove_untranslated",
+            default=False,
+            action="store_true",
+            help="remove untranslated strings from output",
+        )
         self.passthrough.append("remove_untranslated")
 
     def add_threshold_option(self, default=None):
         """Adds an option to output only stores where translation percentage
         exceeds the threshold.
         """
-        self.add_option("", "--threshold", dest="outputthreshold", default=default,
-                        metavar="PERCENT", type="int",
-                        help="only convert files where the translation completion is above PERCENT")
+        self.add_option(
+            "",
+            "--threshold",
+            dest="outputthreshold",
+            default=default,
+            metavar="PERCENT",
+            type="int",
+            help="only convert files where the translation completion is above PERCENT",
+        )
         self.passthrough.append("outputthreshold")
 
     def add_duplicates_option(self, default="msgctxt"):
         """Adds an option to say what to do with duplicate strings."""
         self.add_option(
-            "", "--duplicates", dest="duplicatestyle", default=default,
-            type="choice", choices=["msgctxt", "merge"],
-            help="what to do with duplicate strings (identical source text): merge, msgctxt (default: '%s')" %
-                 default,
-            metavar="DUPLICATESTYLE"
+            "",
+            "--duplicates",
+            dest="duplicatestyle",
+            default=default,
+            type="choice",
+            choices=["msgctxt", "merge"],
+            help="what to do with duplicate strings (identical source text): merge, msgctxt (default: '%s')"
+            % default,
+            metavar="DUPLICATESTYLE",
         )
         self.passthrough.append("duplicatestyle")
 
     def add_multifile_option(self, default="single"):
         """Adds an option to say how to split the po/pot files."""
         self.add_option(
-            "", "--multifile",
-            dest="multifilestyle", default=default,
-            type="choice", choices=["single", "toplevel", "onefile"],
+            "",
+            "--multifile",
+            dest="multifilestyle",
+            default=default,
+            type="choice",
+            choices=["single", "toplevel", "onefile"],
             help="how to split po/pot files (single, toplevel or onefile)",
-            metavar="MULTIFILESTYLE"
+            metavar="MULTIFILESTYLE",
         )
         self.passthrough.append("multifilestyle")
 
-    def potifyformat(self, fileformat):
+    @staticmethod
+    def potifyformat(fileformat):
         """Converts a .po to a .pot where required."""
         if fileformat is None:
             return fileformat
-        elif fileformat == "po":
+        if fileformat == "po":
             return "pot"
-        elif fileformat.endswith(os.extsep + "po"):
+        if fileformat.endswith(os.extsep + "po"):
             return fileformat + "t"
-        else:
-            return fileformat
+        return fileformat
 
     def getformathelp(self, formats):
         """Make a nice help string for describing formats..."""
@@ -121,27 +156,28 @@ class ConvertOptionParser(optrecurse.RecursiveOptionParser, object):
             potformat = self.potifyformat(fileformat)
             if potformat != fileformat:
                 helpformats.append(potformat)
-        return super(ConvertOptionParser, self).getformathelp(helpformats)
+        return super().getformathelp(helpformats)
 
     def filterinputformats(self, options):
         """Filters input formats, processing relevant switches in options."""
         if self.usepots and options.pot:
             return [self.potifyformat(inputformat) for inputformat in self.inputformats]
-        else:
-            return self.inputformats
+        return self.inputformats
 
     def filteroutputoptions(self, options):
         """Filters output options, processing relevant switches in options."""
         if self.usepots and options.pot:
             outputoptions = {}
-            for (inputformat, templateformat), (outputformat, convertor) in six.iteritems(self.outputoptions):
+            for (inputformat, templateformat), (
+                outputformat,
+                convertor,
+            ) in self.outputoptions.items():
                 inputformat = self.potifyformat(inputformat)
                 templateformat = self.potifyformat(templateformat)
                 outputformat = self.potifyformat(outputformat)
                 outputoptions[(inputformat, templateformat)] = (outputformat, convertor)
             return outputoptions
-        else:
-            return self.outputoptions
+        return self.outputoptions
 
     def setpotoption(self):
         """Sets the ``-P``/``--pot`` option depending on input/output formats
@@ -149,18 +185,24 @@ class ConvertOptionParser(optrecurse.RecursiveOptionParser, object):
         """
         if self.usepots:
             potoption = optparse.Option(
-                "-P", "--pot",
-                action="store_true", dest="pot", default=False,
-                help="output PO Templates (.pot) rather than PO files (.po)"
+                "-P",
+                "--pot",
+                action="store_true",
+                dest="pot",
+                default=False,
+                help="output PO Templates (.pot) rather than PO files (.po)",
             )
             self.define_option(potoption)
 
     def settimestampoption(self):
         """Sets ``-S``/``--timestamp`` option."""
         timestampopt = optparse.Option(
-            "-S", "--timestamp",
-            action="store_true", dest="timestamp", default=False,
-            help="skip conversion if the output file has newer timestamp"
+            "-S",
+            "--timestamp",
+            action="store_true",
+            dest="timestamp",
+            default=False,
+            help="skip conversion if the output file has newer timestamp",
         )
         self.define_option(timestampopt)
 
@@ -181,14 +223,15 @@ class ConvertOptionParser(optrecurse.RecursiveOptionParser, object):
             self.error(str(e))
         self.recursiveprocess(options)
 
-    def processfile(self, fileprocessor, options, fullinputpath,
-                    fulloutputpath, fulltemplatepath):
+    def processfile(
+        self, fileprocessor, options, fullinputpath, fulloutputpath, fulltemplatepath
+    ):
         if options.timestamp and _output_is_newer(fullinputpath, fulloutputpath):
             return False
 
-        return super(ConvertOptionParser, self).processfile(
-            fileprocessor, options, fullinputpath, fulloutputpath,
-            fulltemplatepath)
+        return super().processfile(
+            fileprocessor, options, fullinputpath, fulloutputpath, fulltemplatepath
+        )
 
 
 def copyinput(inputfile, outputfile, templatefile, **kwargs):
@@ -203,7 +246,7 @@ def copytemplate(inputfile, outputfile, templatefile, **kwargs):
     return True
 
 
-class Replacer(object):
+class Replacer:
     """An object that knows how to replace strings in files."""
 
     def __init__(self, searchstring, replacestring):
@@ -214,23 +257,21 @@ class Replacer(object):
         """actually replace the text"""
         if self.searchstring is not None and self.replacestring is not None:
             return text.replace(self.searchstring, self.replacestring)
-        else:
-            return text
+        return text
 
-    def searchreplaceinput(self, inputfile, outputfile,
-                           templatefile, **kwargs):
+    def searchreplaceinput(self, inputfile, outputfile, templatefile, **kwargs):
         """copies the input file to the output file, searching and replacing"""
         outputfile.write(self.doreplace(inputfile.read()))
         return True
 
-    def searchreplacetemplate(self, inputfile, outputfile,
-                              templatefile, **kwargs):
+    def searchreplacetemplate(self, inputfile, outputfile, templatefile, **kwargs):
         """Copies the template file to the output file, searching and
         replacing.
         """
         outputfile.write(self.doreplace(templatefile.read()))
         return True
 
+
 # archive files need to know how to:
 # - openarchive: creates an archive object for the archivefilename
 #   * requires a constructor that takes the filename
@@ -257,34 +298,41 @@ class ArchiveConvertOptionParser(ConvertOptionParser):
     as ``(extension, filepurpose)``.
     """
 
-    def __init__(self, formats, usetemplates=False, usepots=False,
-                 description=None, archiveformats=None):
+    def __init__(
+        self,
+        formats,
+        usetemplates=False,
+        usepots=False,
+        description=None,
+        archiveformats=None,
+    ):
         if archiveformats is None:
             self.archiveformats = {}
         else:
             self.archiveformats = archiveformats
         self.archiveoptions = {}
-        ConvertOptionParser.__init__(self, formats, usetemplates, usepots,
-                                     description=description)
+        super().__init__(formats, usetemplates, usepots, description=description)
 
-    def isrecursive(self, fileoption, filepurpose='input'):
+    def isrecursive(self, fileoption, filepurpose="input"):
         """Checks if **fileoption** is a recursive file."""
         if self.isarchive(fileoption, filepurpose):
             return True
-        return super(ArchiveConvertOptionParser, self).isrecursive(fileoption,
-                                                                   filepurpose)
+        return super().isrecursive(fileoption, filepurpose)
 
-    def isarchive(self, fileoption, filepurpose='input'):
+    def isarchive(self, fileoption, filepurpose="input"):
         """Returns whether the file option is an archive file."""
-        if not isinstance(fileoption, six.string_types):
+        if not isinstance(fileoption, str):
             return False
-        mustexist = (filepurpose != 'output')
+        mustexist = filepurpose != "output"
         if mustexist and not os.path.isfile(fileoption):
             return False
         fileext = self.splitext(fileoption)[1]
         # if None is in the archive formats, then treat all non-directory
         # inputs as archives
-        return self.getarchiveclass(fileext, filepurpose, os.path.isdir(fileoption)) is not None
+        return (
+            self.getarchiveclass(fileext, filepurpose, os.path.isdir(fileoption))
+            is not None
+        )
 
     def getarchiveclass(self, fileext, filepurpose, isdir=False):
         """Returns the archiveclass for the given fileext and filepurpose"""
@@ -306,8 +354,9 @@ class ArchiveConvertOptionParser(ConvertOptionParser):
     def openarchive(self, archivefilename, filepurpose, **kwargs):
         """Creates an archive object for the given file."""
         archiveext = self.splitext(archivefilename)[1]
-        archiveclass = self.getarchiveclass(archiveext, filepurpose,
-                                            os.path.isdir(archivefilename))
+        archiveclass = self.getarchiveclass(
+            archiveext, filepurpose, os.path.isdir(archivefilename)
+        )
         archiveoptions = self.archiveoptions.copy()
         archiveoptions.update(kwargs)
         return archiveclass(archivefilename, **archiveoptions)
@@ -316,11 +365,10 @@ class ArchiveConvertOptionParser(ConvertOptionParser):
         """Recurse through archive file / directories and return files to be
         converted.
         """
-        if self.isarchive(options.input, 'input'):
-            options.inputarchive = self.openarchive(options.input, 'input')
+        if self.isarchive(options.input, "input"):
+            options.inputarchive = self.openarchive(options.input, "input")
             return self.recursearchivefiles(options)
-        else:
-            return super(ArchiveConvertOptionParser, self).recurseinputfiles(options)
+        return super().recurseinputfiles(options)
 
     def recursearchivefiles(self, options):
         """Recurse through archive files and convert files."""
@@ -336,111 +384,112 @@ class ArchiveConvertOptionParser(ConvertOptionParser):
 
     def openinputfile(self, options, fullinputpath):
         """Opens the input file."""
-        if self.isarchive(options.input, 'input'):
+        if self.isarchive(options.input, "input"):
             return options.inputarchive.openinputfile(fullinputpath)
         else:
-            return super(ArchiveConvertOptionParser, self).openinputfile(options, fullinputpath)
+            return super().openinputfile(options, fullinputpath)
 
     def getfullinputpath(self, options, inputpath):
         """Gets the absolute path to an input file."""
-        if self.isarchive(options.input, 'input'):
+        if self.isarchive(options.input, "input"):
             return inputpath
-        else:
-            return os.path.join(options.input, inputpath)
+        return os.path.join(options.input, inputpath)
 
     def opentemplatefile(self, options, fulltemplatepath):
         """Opens the template file (if required)."""
         if fulltemplatepath is not None:
-            if (options.recursivetemplate and
-                self.isarchive(options.template, 'template')):
+            if options.recursivetemplate and self.isarchive(
+                options.template, "template"
+            ):
                 # TODO: deal with different names in input/template archives
                 if fulltemplatepath in self.templatearchive:
                     return self.templatearchive.openinputfile(fulltemplatepath)
                 else:
                     self.warning("missing template file %s" % fulltemplatepath)
-        return super(ArchiveConvertOptionParser, self).opentemplatefile(options, fulltemplatepath)
+        return super().opentemplatefile(options, fulltemplatepath)
 
     def getfulltemplatepath(self, options, templatepath):
         """Gets the absolute path to a template file."""
         if templatepath is not None and self.usetemplates and options.template:
-            if self.isarchive(options.template, 'template'):
+            if self.isarchive(options.template, "template"):
                 return templatepath
-            elif not options.recursivetemplate:
+            if not options.recursivetemplate:
                 return templatepath
-            else:
-                return os.path.join(options.template, templatepath)
-        else:
-            return None
+            return os.path.join(options.template, templatepath)
+        return None
 
     def templateexists(self, options, templatepath):
         """Returns whether the given template exists..."""
-        if templatepath is not None:
-            if self.isarchive(options.template, 'template'):
-                # TODO: deal with different names in input/template archives
-                return templatepath in self.templatearchive
-        return super(ArchiveConvertOptionParser, self).templateexists(options, templatepath)
+        if templatepath is not None and self.isarchive(options.template, "template"):
+            # TODO: deal with different names in input/template archives
+            return templatepath in self.templatearchive
+        return super().templateexists(options, templatepath)
 
     def getfulloutputpath(self, options, outputpath):
         """Gets the absolute path to an output file."""
-        if self.isarchive(options.output, 'output'):
+        if self.isarchive(options.output, "output"):
             return outputpath
-        elif options.recursiveoutput and options.output:
+        if options.recursiveoutput and options.output:
             return os.path.join(options.output, outputpath)
-        else:
-            return outputpath
+        return outputpath
 
     def checkoutputsubdir(self, options, subdir):
         """Checks to see if subdir under ``options.output`` needs to be
         created, creates if neccessary.
         """
-        if not self.isarchive(options.output, 'output'):
-            super(ArchiveConvertOptionParser, self).checkoutputsubdir(options, subdir)
+        if not self.isarchive(options.output, "output"):
+            super().checkoutputsubdir(options, subdir)
 
     def openoutputfile(self, options, fulloutputpath):
         """Opens the output file."""
-        if self.isarchive(options.output, 'output'):
+        if self.isarchive(options.output, "output"):
             outputstream = self.outputarchive.openoutputfile(fulloutputpath)
             if outputstream is None:
-                self.warning("Could not find where to put %s in output "
-                             "archive; writing to tmp" % fulloutputpath)
+                self.warning(
+                    "Could not find where to put %s in output "
+                    "archive; writing to tmp" % fulloutputpath
+                )
                 return BytesIO()
             return outputstream
         else:
-            return super(ArchiveConvertOptionParser, self).openoutputfile(options, fulloutputpath)
+            return super().openoutputfile(options, fulloutputpath)
 
     def recursiveprocess(self, options):
         """Recurse through directories and convert files."""
         if hasattr(options, "multifilestyle"):
-            self.archiveoptions = {'multifilestyle': options.multifilestyle}
+            self.archiveoptions = {"multifilestyle": options.multifilestyle}
             for filetype in ("input", "output", "template"):
                 allowoption = "allowrecursive%s" % filetype
-                if (options.multifilestyle == "onefile" and
-                    getattr(options, allowoption, True)):
+                if options.multifilestyle == "onefile" and getattr(
+                    options, allowoption, True
+                ):
                     setattr(options, allowoption, False)
 
-        if (self.usetemplates and options.template and
-            self.isarchive(options.template, 'template')):
-            self.templatearchive = self.openarchive(options.template, 'template')
+        if (
+            self.usetemplates
+            and options.template
+            and self.isarchive(options.template, "template")
+        ):
+            self.templatearchive = self.openarchive(options.template, "template")
 
-        if options.output and self.isarchive(options.output, 'output'):
-            self.outputarchive = self.openarchive(options.output, 'output',
-                                                  mode="w")
-        return super(ArchiveConvertOptionParser, self).recursiveprocess(options)
+        if options.output and self.isarchive(options.output, "output"):
+            self.outputarchive = self.openarchive(options.output, "output", mode="w")
+        return super().recursiveprocess(options)
 
-    def processfile(self, fileprocessor, options, fullinputpath,
-                    fulloutputpath, fulltemplatepath):
-        """Run an invidividual conversion."""
+    def processfile(
+        self, fileprocessor, options, fullinputpath, fulloutputpath, fulltemplatepath
+    ):
+        """Run an individual conversion."""
         if options.timestamp and _output_is_newer(fullinputpath, fulloutputpath):
             return False
 
-        if self.isarchive(options.output, 'output'):
+        if self.isarchive(options.output, "output"):
             inputfile = self.openinputfile(options, fullinputpath)
             # TODO: handle writing back to same archive as input/template
             templatefile = self.opentemplatefile(options, fulltemplatepath)
             outputfile = self.openoutputfile(options, fulloutputpath)
             passthroughoptions = self.getpassthroughoptions(options)
-            if fileprocessor(inputfile, outputfile, templatefile,
-                             **passthroughoptions):
+            if fileprocessor(inputfile, outputfile, templatefile, **passthroughoptions):
                 if not outputfile.isatty():
                     outputfile.close()
                 return True
@@ -450,9 +499,9 @@ class ArchiveConvertOptionParser(ConvertOptionParser):
                     os.unlink(fulloutputpath)
                 return False
         else:
-            return super(ArchiveConvertOptionParser, self).processfile(
-                fileprocessor, options, fullinputpath, fulloutputpath,
-                fulltemplatepath)
+            return super().processfile(
+                fileprocessor, options, fullinputpath, fulloutputpath, fulltemplatepath
+            )
 
 
 def _output_is_newer(input_path, output_path):
@@ -479,11 +528,13 @@ def should_output_store(store, threshold):
     if not threshold:
         return True
 
-    from translate.storage import statsdb
+    from translate.tools import pocount
 
     units = list(filter(lambda unit: unit.istranslatable(), store.units))
     translated = list(filter(lambda unit: unit.istranslated(), units))
-    wordcounts = dict(map(lambda unit: (unit.getid(), statsdb.wordsinunit(unit)), units))
+    wordcounts = dict(
+        map(lambda unit: (unit.getid(), pocount.wordsinunit(unit)), units)
+    )
 
     def sourcewords(elementlist):
         return sum(map(lambda unit: wordcounts[unit.getid()][0], elementlist))
