@@ -57,7 +57,7 @@ class oo2xliff:
             unit.markfuzzy(False)
         else:
             unit.markfuzzy(True)
-        unit.addlocation(key + "." + subkey)
+        unit.setid(key + "." + subkey)
         if getattr(translators_comment, subkey).strip() != "":
             unit.addnote(getattr(translators_comment, subkey), origin="developer")
         return unit
