@@ -30,7 +30,6 @@ from translate.convert import convert
 from translate.filters import autocorrect, checks, pofilter
 from translate.storage import factory, oo
 
-
 logger = logging.getLogger(__name__)
 
 
@@ -160,20 +159,19 @@ class oocheckfilter(pofilter.pocheckfilter):
         if filteraction == "none":
             return True
         filterresult = self.filterunit(unit)
-        if filterresult:
-            if filterresult != autocorrect:
-                for filtername, filtermessage in filterresult.items():
-                    location = unit.getlocations()[0].encode("utf-8")
-                    if filtername in self.options.error:
-                        logger.error(
-                            "Error at %s::%s: %s", filename, location, filtermessage
-                        )
-                        return filteraction not in ["exclude-all", "exclude-serious"]
-                    if filtername in self.options.warning or self.options.alwayswarn:
-                        logger.warning(
-                            "Warning at %s::%s: %s", filename, location, filtermessage
-                        )
-                        return filteraction not in ["exclude-all"]
+        if filterresult and filterresult != autocorrect:
+            for filtername, filtermessage in filterresult.items():
+                location = unit.getlocations()[0].encode("utf-8")
+                if filtername in self.options.error:
+                    logger.error(
+                        "Error at %s::%s: %s", filename, location, filtermessage
+                    )
+                    return filteraction not in ["exclude-all", "exclude-serious"]
+                if filtername in self.options.warning or self.options.alwayswarn:
+                    logger.warning(
+                        "Warning at %s::%s: %s", filename, location, filtermessage
+                    )
+                    return filteraction not in ["exclude-all"]
         return True
 
 
