@@ -83,7 +83,8 @@ class TestPO2RESX:
   %s
 </root>"""
 
-    def po2resx(self, resxsource, po_source):
+    @staticmethod
+    def po2resx(resxsource, po_source):
         """Helper that merges po translations to .resx source without requiring files"""
         po_store = po.pofile(po_source.encode("utf-8"))
         template_file = BytesIO(resxsource.encode())
@@ -563,8 +564,8 @@ class TestPO2RESXCommand(test_convert.TestConvertCommand, TestPO2RESX):
     """Tests running actual po2resx commands on files"""
 
     convertmodule = po2resx
-
-    def test_help(self, capsys):
-        """Tests getting help"""
-        options = super().test_help(capsys)
-        options = self.help_check(options, "-t TEMPLATE, --template=TEMPLATE")
+    expected_options = [
+        "-t TEMPLATE, --template=TEMPLATE",
+        "--fuzzy",
+        "--nofuzzy",
+    ]
