@@ -6,7 +6,6 @@ from translate.convert import po2yaml, test_convert
 
 
 class TestPO2YAML:
-
     ConverterClass = po2yaml.po2yaml
 
     def _convert(
@@ -202,11 +201,9 @@ class TestPO2YAMLCommand(test_convert.TestConvertCommand, TestPO2YAML):
 
     convertmodule = po2yaml
     defaultoptions = {"progress": "none"}
-
-    def test_help(self, capsys):
-        """tests getting help"""
-        options = test_convert.TestConvertCommand.test_help(self, capsys)
-        options = self.help_check(options, "-t TEMPLATE, --template=TEMPLATE")
-        options = self.help_check(options, "--threshold=PERCENT")
-        options = self.help_check(options, "--fuzzy")
-        options = self.help_check(options, "--nofuzzy")
+    expected_options = [
+        "-t TEMPLATE, --template=TEMPLATE",
+        "--threshold=PERCENT",
+        "--fuzzy",
+        "--nofuzzy",
+    ]
