@@ -31,7 +31,8 @@ class web2py2po:
         self.mypofile = pofile
         self.duplicatestyle = duplicatestyle
 
-    def convertunit(self, source_str, target_str):
+    @staticmethod
+    def convertunit(source_str, target_str):
         pounit = po.pounit(encoding="UTF-8")
         pounit.settypecomment("python-format")
         pounit.source = source_str
@@ -57,7 +58,6 @@ class web2py2po:
 
 
 def convertpy(inputfile, outputfile, encoding="UTF-8", duplicatestyle="msgctxt"):
-
     new_pofile = po.pofile()
     convertor = web2py2po(new_pofile)
 
