@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2013 Zuza Software Foundation
 #
@@ -19,10 +18,9 @@
 
 """This module represents the Akan language.
 
-.. seealso:: http://en.wikipedia.org/wiki/Akan_language
+.. seealso:: :wp:`Akan_language`
 """
 
-from __future__ import unicode_literals
 
 from translate.lang import common
 
