@@ -27,7 +27,6 @@ those objects.
 
 from xml.dom import expatbuilder, minidom
 
-
 # helper functions we use to do xml the way we want, used by modified
 # classes below
 
@@ -46,9 +45,9 @@ def writexml_helper(self, writer, indent="", addindent="", newl=""):
     a_names = sorted(attrs.keys())
 
     for a_name in a_names:
-        writer.write(" %s=\"" % a_name)
+        writer.write(' %s="' % a_name)
         minidom._write_data(writer, attrs[a_name].value)
-        writer.write("\"")
+        writer.write('"')
     if self.childNodes:
         # We need to write text nodes without newline and indentation, so
         # we handle them differently. Note that we here assume that "empty"
@@ -65,14 +64,14 @@ def writexml_helper(self, writer, indent="", addindent="", newl=""):
             writer.write(">")
             for node in self.childNodes:
                 node.writexml(writer, "", "", "")
-            writer.write("</%s>%s" % (self.tagName, newl))
+            writer.write(f"</{self.tagName}>{newl}")
         else:
             # This is the normal case that we do with pretty layout
             writer.write(">%s" % (newl))
             for node in self.childNodes:
                 if node.nodeType != self.TEXT_NODE:
                     node.writexml(writer, (indent + addindent), addindent, newl)
-            writer.write("%s</%s>%s" % (indent, self.tagName, newl))
+            writer.write(f"{indent}</{self.tagName}>{newl}")
     else:
         writer.write("/>%s" % (newl))
 
@@ -85,22 +84,22 @@ def getElementsByTagName_helper(parent, name, dummy=None):
     yieldElementsByTagName
     """
     for node in parent.childNodes:
-        if (node.nodeType == minidom.Node.ELEMENT_NODE and
-            (name == "*" or node.tagName == name)):
+        if node.nodeType == minidom.Node.ELEMENT_NODE and (
+            name == "*" or node.tagName == name
+        ):
             yield node
         if node.hasChildNodes():
-            for othernode in node.getElementsByTagName(name):
-                yield othernode
+            yield from node.getElementsByTagName(name)
 
 
 def searchElementsByTagName_helper(parent, name, onlysearch):
     """limits the search to within tags occuring in onlysearch"""
     for node in parent.childNodes:
-        if (node.nodeType == minidom.Node.ELEMENT_NODE and
-            (name == "*" or node.tagName == name)):
+        if node.nodeType == minidom.Node.ELEMENT_NODE and (
+            name == "*" or node.tagName == name
+        ):
             yield node
-        if (node.nodeType == minidom.Node.ELEMENT_NODE and
-            node.tagName in onlysearch):
+        if node.nodeType == minidom.Node.ELEMENT_NODE and node.tagName in onlysearch:
             for node in node.searchElementsByTagName(name, onlysearch):
                 yield node
 
@@ -114,19 +113,18 @@ def getnodetext(node):
     """returns the node's text by iterating through the child nodes"""
     if node is None:
         return ""
-    return "".join([t.data for t in node.childNodes if t.nodeType == t.TEXT_NODE])
+    return "".join(t.data for t in node.childNodes if t.nodeType == t.TEXT_NODE)
+
 
 # various modifications to minidom classes to add functionality we like
 
 
 class DOMImplementation(minidom.DOMImplementation):
-
     def _create_document(self):
         return Document()
 
 
 class Element(minidom.Element):
-
     def yieldElementsByTagName(self, name):
         return getElementsByTagName_helper(self, name)
 
@@ -164,11 +162,11 @@ theDOMImplementation = DOMImplementation()
 
 
 class ExpatBuilderNS(expatbuilder.ExpatBuilderNS):
-
     def reset(self):
         """Free all data structures used during DOM construction."""
         self.document = theDOMImplementation.createDocument(
-            expatbuilder.EMPTY_NAMESPACE, None, None)
+            expatbuilder.EMPTY_NAMESPACE, None, None
+        )
         self.curNode = self.document
         self._elem_info = self.document._elem_info
         self._cdata = False
@@ -178,7 +176,7 @@ class ExpatBuilderNS(expatbuilder.ExpatBuilderNS):
         # All we want to do is construct our own Element instead of
         # minidom.Element, unfortunately the only way to do this is to
         # copy this whole function from expatbuilder.py
-        if ' ' in name:
+        if " " in name:
             uri, localname, prefix, qname = expatbuilder._parse_ns_name(self, name)
         else:
             uri = expatbuilder.EMPTY_NAMESPACE
@@ -194,32 +192,45 @@ class ExpatBuilderNS(expatbuilder.ExpatBuilderNS):
             for prefix, uri in self._ns_ordered_prefixes:
                 if prefix:
                     a = minidom.Attr(
-                        expatbuilder._intern(self, 'xmlns:' + prefix),
-                        expatbuilder.XMLNS_NAMESPACE, prefix, "xmlns")
+                        expatbuilder._intern(self, "xmlns:" + prefix),
+                        expatbuilder.XMLNS_NAMESPACE,
+                        prefix,
+                        "xmlns",
+                    )
                 else:
-                    a = minidom.Attr("xmlns", expatbuilder.XMLNS_NAMESPACE,
-                                     "xmlns", expatbuilder.EMPTY_PREFIX)
+                    a = minidom.Attr(
+                        "xmlns",
+                        expatbuilder.XMLNS_NAMESPACE,
+                        "xmlns",
+                        expatbuilder.EMPTY_PREFIX,
+                    )
                 a.value = uri
                 a.ownerDocument = self.document
                 expatbuilder._set_attribute_node(node, a)
             del self._ns_ordered_prefixes[:]
 
         if attributes:
-            if hasattr(node, '_ensure_attributes'):
+            if hasattr(node, "_ensure_attributes"):
                 node._ensure_attributes()  # Python 3 only
             _attrs = node._attrs
             _attrsNS = node._attrsNS
             for i in range(0, len(attributes), 2):
                 aname = attributes[i]
-                value = attributes[i+1]
-                if ' ' in aname:
-                    uri, localname, prefix, qname = expatbuilder._parse_ns_name(self, aname)
+                value = attributes[i + 1]
+                if " " in aname:
+                    uri, localname, prefix, qname = expatbuilder._parse_ns_name(
+                        self, aname
+                    )
                     a = minidom.Attr(qname, uri, localname, prefix)
                     _attrs[qname] = a
                     _attrsNS[(uri, localname)] = a
                 else:
-                    a = minidom.Attr(aname, expatbuilder.EMPTY_NAMESPACE,
-                                     aname, expatbuilder.EMPTY_PREFIX)
+                    a = minidom.Attr(
+                        aname,
+                        expatbuilder.EMPTY_NAMESPACE,
+                        aname,
+                        expatbuilder.EMPTY_PREFIX,
+                    )
                     _attrs[aname] = a
                     _attrsNS[(expatbuilder.EMPTY_NAMESPACE, aname)] = a
                 a.ownerDocument = self.document
@@ -234,19 +245,24 @@ class ExpatBuilderNS(expatbuilder.ExpatBuilderNS):
 
         def end_element_handler(self, name):
             curNode = self.curNode
-            if ' ' in name:
+            if " " in name:
                 uri, localname, prefix, qname = expatbuilder._parse_ns_name(self, name)
-                assert (curNode.namespaceURI == uri
-                        and curNode.localName == localname
-                        and curNode.prefix == prefix), "element stack messed up! (namespace)"
+                assert (
+                    curNode.namespaceURI == uri
+                    and curNode.localName == localname
+                    and curNode.prefix == prefix
+                ), "element stack messed up! (namespace)"
             else:
-                assert curNode.nodeName == name, \
-                    "element stack messed up - bad nodeName"
-                assert curNode.namespaceURI == expatbuilder.EMPTY_NAMESPACE, \
-                    "element stack messed up - bad namespaceURI"
+                assert (
+                    curNode.nodeName == name
+                ), "element stack messed up - bad nodeName"
+                assert (
+                    curNode.namespaceURI == expatbuilder.EMPTY_NAMESPACE
+                ), "element stack messed up - bad namespaceURI"
             self.curNode = curNode.parentNode
             self._finish_end_element(curNode)
 
+
 # parser methods that use our modified xml classes
 
 
@@ -254,7 +270,7 @@ def parse(file, parser=None, bufsize=None):
     """Parse a file into a DOM by filename or file object."""
     builder = ExpatBuilderNS()
     if isinstance(file, str):
-        with open(file, 'rb') as fp:
+        with open(file, "rb") as fp:
             result = builder.parseFile(fp)
     else:
         result = builder.parseFile(file)
