@@ -250,8 +250,7 @@ class JsonFile(base.DictStore):
 
 
 class JsonNestedUnit(BaseJsonUnit):
-    def storevalues(self, output):
-        self.storevalue(output, self.converttarget())
+    """A nested JSON entry"""
 
 
 class JsonNestedFile(JsonFile):
@@ -481,9 +480,7 @@ class I18NextV4File(JsonNestedFile):
                     plural_base, suffix = k.rsplit("_", 1)
 
                 if suffix in cldr_plural_categories:
-                    plurals = [
-                        f"{plural_base}_{suffix}" for suffix in cldr_plural_categories
-                    ]
+                    plurals = [f"{plural_base}_{suffix}" for suffix in self.plural_tags]
 
                 if plurals:
                     sources = []
@@ -655,8 +652,8 @@ class GoI18NJsonFile(JsonFile):
 
     See following URLs for doc:
 
-    https://github.com/nicksnyder/go-i18n
-    https://godoc.org/github.com/nicksnyder/go-i18n/v2
+    https://github.com/nicksnyder/go-i18n/tree/v1
+    https://pkg.go.dev/github.com/nicksnyder/go-i18n
     """
 
     UnitClass = GoI18NJsonUnit
@@ -695,6 +692,66 @@ class GoI18NJsonFile(JsonFile):
         out.write(b"\n")
 
 
+class GoI18NV2JsonUnit(BaseJsonUnit):
+    ID_FORMAT = "{}"
+
+    def converttarget(self):
+        # Special handling of single translations
+        if not isinstance(self.target, multistring) or len(self.target.strings) == 1:
+            if self.notes:
+                return {"description": self.notes, "other": self.target}
+            else:
+                return self.target
+
+        target = {}
+        if self.notes:
+            target["description"] = self.notes
+
+        strings = self.target.strings
+        if len(self._store.plural_tags) > len(strings):
+            strings += [""] * (len(self._store.plural_tags) - len(target.strings))
+        for offset, plural in enumerate(self._store.plural_tags):
+            target[plural] = strings[offset]
+
+        return target
+
+
+class GoI18NV2JsonFile(JsonFile):
+    """go-i18n v2 JSON file
+
+    See following URLs for doc:
+
+    https://github.com/nicksnyder/go-i18n
+    https://pkg.go.dev/github.com/nicksnyder/go-i18n/v2
+    """
+
+    UnitClass = GoI18NV2JsonUnit
+
+    def _extract_units(
+        self,
+        data,
+        stop=None,
+        prev=None,
+        name_node=None,
+        name_last_node=None,
+        last_node=None,
+    ):
+        for id, value in data.items():
+            if isinstance(value, str):
+                unit = self.UnitClass(value, id)
+            else:
+                translation = multistring(
+                    [value.get(key) for key in cldr_plural_categories if key in value]
+                )
+                unit = self.UnitClass(
+                    translation,
+                    id,
+                    value.get("description", ""),
+                )
+            unit.setid(id)
+            yield unit
+
+
 class ARBJsonUnit(BaseJsonUnit):
     ID_FORMAT = "{}"
 
