@@ -37,7 +37,6 @@ from io import BytesIO
 
 from translate.misc import quote, wStringIO
 
-
 # File normalisation
 
 normalfilenamechars = (
@@ -316,7 +315,7 @@ class oounit:
                 lines = [new_line]
         else:
             lines = self.lines
-        return "\r\n".join([str(line) for line in lines])
+        return "\r\n".join(str(line) for line in lines)
 
 
 class oofile:
@@ -338,7 +337,7 @@ class oofile:
     def addline(self, thisline):
         """adds a parsed line to the file"""
         key = thisline.getkey()
-        element = self.ookeys.get(key, None)
+        element = self.ookeys.get(key)
         if element is None:
             element = self.UnitClass()
             self.units.append(element)
