@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2009-2010 Zuza Software Foundation
 #
@@ -24,12 +23,15 @@ fit into any other sub-category.
 
 import re
 
-import six
-
 from translate.storage.placeables.base import G, Ph, StringElem
 
-
-__all__ = ('AltAttrPlaceable', 'XMLEntityPlaceable', 'XMLTagPlaceable', 'parsers', 'to_general_placeables')
+__all__ = (
+    "AltAttrPlaceable",
+    "XMLEntityPlaceable",
+    "XMLTagPlaceable",
+    "parsers",
+    "to_general_placeables",
+)
 
 
 def regex_parse(cls, pstr):
@@ -65,7 +67,7 @@ class NewlinePlaceable(Ph):
     iseditable = False
     isfragile = True
     istranslatable = False
-    regex = re.compile(r'\r\n|\n|\r')
+    regex = re.compile(r"\r\n|\n|\r")
     parse = classmethod(regex_parse)
 
 
@@ -73,7 +75,7 @@ class NumberPlaceable(Ph):
     """Placeable for numbers."""
 
     istranslatable = False
-    regex = re.compile(u"[-+]?[0-9]+([\u00a0.,][0-9]+)*")
+    regex = re.compile("[-+]?[0-9]+([\u00a0.,][0-9]+)*")
     parse = classmethod(regex_parse)
 
 
@@ -93,12 +95,14 @@ class QtFormattingPlaceable(Ph):
 
     iseditable = False
     istranslatable = False
-    regex = re.compile(r"""(?x)
+    regex = re.compile(
+        r"""(?x)
                        %                 # Start of a place marker
                        L?                # The sequence is replaced with a localized representation (optional)
                        [1-9]\d{0,1}      # Place marker numbers must be in the range 1 to 99.
                        (?=([^\d]|$))     # Double check that we aren't matching %100+ (non consuming match)
-                       """)
+                       """
+    )
     parse = classmethod(regex_parse)
 
 
@@ -112,15 +116,17 @@ class PythonFormattingPlaceable(Ph):
     iseditable = False
     istranslatable = False
     # Need to correctly define a python identifier.
-    regex = re.compile(r"""(?x)
+    regex = re.compile(
+        r"""(?x)
                        %                     # Start of formatting specifier
                        (%|                   # No argument converted %% creates a %
-                       (\([a-z_]+\)){0,1}    # Mapping key value (optional)
+                       (\([^)]+\)){0,1}      # Mapping key value (optional)
                        [\-\+0\s\#]{0,1}      # Conversion flags (optional)
                        (\d+|\*){0,1}         # Minimum field width (optional)
                        (\.(\d+|\*)){0,1}     # Precision (optional)
                        [hlL]{0,1}            # Length modifier (optional)
-                       [diouxXeEfFgGcrs]{1}) # Conversion type""")
+                       [diouxXeEfFgGcrs]{1}) # Conversion type"""
+    )
     parse = classmethod(regex_parse)
 
 
@@ -139,7 +145,8 @@ class JavaMessageFormatPlaceable(Ph):
     iseditable = False  # TODO: Technically incorrect as you need to change
     istranslatable = False
     # things in a choice entry
-    regex = re.compile(r"""(?x)
+    regex = re.compile(
+        r"""(?x)
       {                      # Start of MessageFormat
       [0-9]+                 # Number, positive array reference
       (,\s*                  # FormatType (optional) one of number,date,time,choice
@@ -147,7 +154,8 @@ class JavaMessageFormatPlaceable(Ph):
          (date|time)(,\s*(short|medium|long|full|.+?))?|                  # date/time FormatStyle (optional)
          choice,([^{]+({.+})?)+)?                                      # choice with format, format required
       )?                     # END: (optional) FormatType
-      }                      # END: MessageFormat""")
+      }                      # END: MessageFormat"""
+    )
     parse = classmethod(regex_parse)
 
 
@@ -159,7 +167,8 @@ class FormattingPlaceable(Ph):
 
     iseditable = False
     istranslatable = False
-    regex = re.compile(r"""
+    regex = re.compile(
+        r"""
         %                         # introduction
         (\d+\$)?                  # selection of non-next variable (reordering)
         [\-\+0 \#'I]?             # optional flag
@@ -167,7 +176,9 @@ class FormattingPlaceable(Ph):
         (\.\d+)?                  # precision
         [hlI]?                    # length
         [cCdiouxXeEfgGnpsS]       # conversion specifier
-        """, re.VERBOSE)
+        """,
+        re.VERBOSE,
+    )
     parse = classmethod(regex_parse)
 
 
@@ -193,7 +204,8 @@ class UrlPlaceable(Ph):
     """Placeable handling URI."""
 
     istranslatable = False
-    regex = re.compile(r"""
+    regex = re.compile(
+        r"""
     ((((news|nttp|file|https?|ftp|irc)://)       # has to start with a protocol
     |((www|ftp)[-A-Za-z0-9]*\.))                 # or www... or ftp... hostname
     ([-A-Za-z0-9]+(\.[-A-Za-z0-9]+)*)            # hostname
@@ -201,7 +213,9 @@ class UrlPlaceable(Ph):
     (:[0-9]{1,5})?                               # optional port
     (/[-A-Za-z0-9_\$\.\+\!\*\(\),;:@&=\?/~\#\%]*)?     # optional trailing path
     (?=$|\s|([]'}>\),\"]))
-    """, re.VERBOSE)
+    """,
+        re.VERBOSE,
+    )
     parse = classmethod(regex_parse)
 
 
@@ -221,7 +235,9 @@ class EmailPlaceable(Ph):
     """Placeable handling emails."""
 
     istranslatable = False
-    regex = re.compile(r"((mailto:)|)[A-Za-z0-9]+[-a-zA-Z0-9._%]*@(([-A-Za-z0-9]+)\.)+[a-zA-Z]{2,4}")
+    regex = re.compile(
+        r"((mailto:)|)[A-Za-z0-9]+[-a-zA-Z0-9._%]*@(([-A-Za-z0-9]+)\.)+[a-zA-Z]{2,4}"
+    )
     # TODO: What about internationalised domain names? ;-)
     parse = classmethod(regex_parse)
 
@@ -235,7 +251,7 @@ class PunctuationPlaceable(Ph):
     # is available on the translators keyboard.  Or easily expanded by their
     # configuration.
     regex = re.compile(
-        u'''([™©®]|          # Marks
+        """([™©®]|          # Marks
              [℃℉°]|          # Degree related
              [±πθ×÷−√∞∆Σ′″]| # Maths
              [‘’ʼ‚‛“”„‟]|    # Quote characters
@@ -245,8 +261,8 @@ class PunctuationPlaceable(Ph):
              —|              # U2014 - em dash
              –|              # U2013 - en dash
              [ ]             # U202F - narrow no-break space
-            )+''',
-        re.VERBOSE
+            )+""",
+        re.VERBOSE,
     )
     parse = classmethod(regex_parse)
 
@@ -256,10 +272,13 @@ class XMLEntityPlaceable(Ph):
 
     iseditable = False
     istranslatable = False
-    regex = re.compile(r'''&(
+    regex = re.compile(
+        r"""&(
         ([a-zA-Z][a-zA-Z0-9\.-]*)            #named entity
          |([#](\d{1,5}|x[a-fA-F0-9]{1,5})+)  #numeric entity
-        );''', re.VERBOSE)
+        );""",
+        re.VERBOSE,
+    )
     parse = classmethod(regex_parse)
 
 
@@ -267,7 +286,7 @@ class CapsPlaceable(Ph):
     """Placeable handling long all-caps strings."""
 
     iseditable = True
-    regex = re.compile(r'\b[A-Z][A-Z_/\-:*0-9]{2,}\b[+]?')
+    regex = re.compile(r"\b[A-Z][A-Z_/\-:*0-9]{2,}\b[+]?")
     parse = classmethod(regex_parse)
 
 
@@ -275,13 +294,15 @@ class CamelCasePlaceable(Ph):
     """Placeable handling camel case strings."""
 
     iseditable = True
-    regex = re.compile(r'''(?x)
+    regex = re.compile(
+        r"""(?x)
             \b(
                [a-z]+[A-Z]|         #Not that strict if we start with lower (iPod)
                [A-Z]+[a-z]+[A-Z]|   #One capital at the start is not enough (OpenTran)
                [A-Z]{2,}[a-z]       #Two capitals at the start is enough (KBabel)
             )[a-zA-Z0-9]*           #Let's allow any final lower/upper/digit
-            \b''')
+            \b"""
+    )
     parse = classmethod(regex_parse)
 
 
@@ -290,10 +311,13 @@ class SpacesPlaceable(Ph):
 
     iseditable = True
     istranslatable = False
-    regex = re.compile(r"""(?m)  #Multiline expression
+    regex = re.compile(
+        r"""(?m)  #Multiline expression
         [ ]{2,}|     #More than two consecutive
         ^[ ]+|       #At start of a line
-        [ ]+$        #At end of line""", re.VERBOSE)
+        [ ]+$        #At end of line""",
+        re.VERBOSE,
+    )
 
     parse = classmethod(regex_parse)
 
@@ -303,14 +327,17 @@ class XMLTagPlaceable(Ph):
 
     iseditable = True
     istranslatable = False
-    regex = re.compile(r'''
+    regex = re.compile(
+        r"""
         <                         # start of opening tag
         ([\w.:]+)                 # tag name, possibly namespaced
         (\s([\w.:]+=              # space and attribute name followed by =
             ((".*?")|('.*?'))     # attribute value, single or double quoted
         )?)*/?>                   # end of opening tag, possibly self closing
         |</([\w.]+)>              # or a closing tag
-        ''', re.VERBOSE)
+        """,
+        re.VERBOSE,
+    )
     parse = classmethod(regex_parse)
 
 
@@ -318,27 +345,33 @@ class OptionPlaceable(Ph):
     """Placeble handling command line options e.g. --help"""
 
     istranslatable = False
-    regex = re.compile(r'''(?x)
+    regex = re.compile(
+        r"""(?x)
                       \B(             # Empty string at the start of a non-word, ensures [space]-
                         -[a-zA-Z]|    # Single letter options: -i, -I
                         --[a-z\-]+    # Word options: --help
-                      )\b''')
-    #regex = re.compile(r'''(-[a-zA-Z]|--[-a-z]+)\b''')
+                      )\b"""
+    )
+    # regex = re.compile(r'''(-[a-zA-Z]|--[-a-z]+)\b''')
     parse = classmethod(regex_parse)
 
 
-def to_general_placeables(tree,
-                          classmap={
-                              G: (AltAttrPlaceable,),
-                              Ph: (NumberPlaceable,
-                                   XMLEntityPlaceable,
-                                   XMLTagPlaceable,
-                                   UrlPlaceable,
-                                   FilePlaceable,
-                                   EmailPlaceable,
-                                   OptionPlaceable,
-                                   PunctuationPlaceable,),
-                          }):
+def to_general_placeables(
+    tree,
+    classmap={
+        G: (AltAttrPlaceable,),
+        Ph: (
+            NumberPlaceable,
+            XMLEntityPlaceable,
+            XMLTagPlaceable,
+            UrlPlaceable,
+            FilePlaceable,
+            EmailPlaceable,
+            OptionPlaceable,
+            PunctuationPlaceable,
+        ),
+    },
+):
     if not isinstance(tree, StringElem):
         return tree
 
@@ -346,7 +379,7 @@ def to_general_placeables(tree,
 
     for baseclass, gclasslist in classmap.items():
         if isinstance(tree, baseclass):
-            gclass = [c for c in gclasslist if c.parse(six.text_type(tree))]
+            gclass = [c for c in gclasslist if c.parse(str(tree))]
             if gclass:
                 newtree = gclass[0]()
 
