@@ -22,7 +22,6 @@ from urllib import parse
 from translate.storage import base, poheader
 from translate.storage.workflow import StateEnum as state
 
-
 msgid_comment_re = re.compile("_: (.*?)\n")
 
 
@@ -40,7 +39,7 @@ def extract_msgid_comment(text):
 
 def quote_plus(text):
     """Quote the query fragment of a URL; replacing ' ' with '+'"""
-    return parse.quote_plus(text.encode("utf-8"), safe='[]()/:,@')
+    return parse.quote_plus(text.encode("utf-8"), safe="[]()/:,@")
 
 
 def unquote_plus(text):
@@ -71,19 +70,19 @@ class pounit(base.TranslationUnit):
 
     def adderror(self, errorname, errortext):
         """Adds an error message to this unit."""
-        text = '(pofilter) %s: %s' % (errorname, errortext)
+        text = f"(pofilter) {errorname}: {errortext}"
         # Don't add the same error twice:
-        if text not in self.getnotes(origin='translator'):
+        if text not in self.getnotes(origin="translator"):
             self.addnote(text, origin="translator")
 
     def geterrors(self):
         """Get all error messages."""
-        notes = self.getnotes(origin="translator").split('\n')
+        notes = self.getnotes(origin="translator").split("\n")
         errordict = {}
         for note in notes:
-            if '(pofilter) ' in note:
-                error = note.replace('(pofilter) ', '')
-                errorname, errortext = error.split(': ', 1)
+            if "(pofilter) " in note:
+                error = note.replace("(pofilter) ", "")
+                errorname, errortext = error.split(": ", 1)
                 errordict[errorname] = errortext
         return errordict
 
@@ -97,12 +96,12 @@ class pounit(base.TranslationUnit):
         else:
             # Strip (review) notes.
             notestring = self.getnotes(origin="translator")
-            notes = notestring.split('\n')
+            notes = notestring.split("\n")
             newnotes = []
             for note in notes:
-                if '(review)' not in note:
+                if "(review)" not in note:
                     newnotes.append(note)
-            newnotes = '\n'.join(newnotes)
+            newnotes = "\n".join(newnotes)
             self.removenotes()
             self.addnote(newnotes, origin="translator")
 
@@ -119,7 +118,11 @@ class pounit(base.TranslationUnit):
         return self.hasmarkedcomment("review") or self.hasmarkedcomment("pofilter")
 
     def isobsolete(self):
-        return self.STATE[self.S_FUZZY_OBSOLETE][0] <= self.get_state_n() < self.STATE[self.S_OBSOLETE][1]
+        return (
+            self.STATE[self.S_FUZZY_OBSOLETE][0]
+            <= self.get_state_n()
+            < self.STATE[self.S_OBSOLETE][1]
+        )
 
     def isfuzzy(self):
         # implementation specific fuzzy detection, must not use get_state_n()
@@ -169,8 +172,12 @@ class pounit(base.TranslationUnit):
         else:
             has_target = bool(self.target)
         if has_target:
-            isfuzzy = self.STATE[self.S_FUZZY][0] <= value < self.STATE[self.S_FUZZY][1] or \
-                self.STATE[self.S_FUZZY_OBSOLETE][0] <= value < self.STATE[self.S_FUZZY_OBSOLETE][1]
+            isfuzzy = (
+                self.STATE[self.S_FUZZY][0] <= value < self.STATE[self.S_FUZZY][1]
+                or self.STATE[self.S_FUZZY_OBSOLETE][0]
+                <= value
+                < self.STATE[self.S_FUZZY_OBSOLETE][1]
+            )
             self._domarkfuzzy(isfuzzy)  # Implementation specific fuzzy-marking
         else:
             super().set_state_n(self.S_UNTRANSLATED)
@@ -179,14 +186,19 @@ class pounit(base.TranslationUnit):
 
 class pofile(poheader.poheader, base.TranslationStore):
     Name = "Gettext PO file"  # pylint: disable=E0602
-    Mimetypes = ["text/x-gettext-catalog", "text/x-gettext-translation", "text/x-po", "text/x-pot"]
+    Mimetypes = [
+        "text/x-gettext-catalog",
+        "text/x-gettext-translation",
+        "text/x-po",
+        "text/x-pot",
+    ]
     Extensions = ["po", "pot"]
     # We don't want windows line endings on Windows:
     _binary = True
 
     def __init__(self, inputfile=None, noheader=False, **kwargs):
         super().__init__(**kwargs)
-        self.filename = ''
+        self.filename = ""
         if inputfile is not None:
             self.parse(inputfile)
         elif not noheader:
@@ -195,4 +207,4 @@ class pofile(poheader.poheader, base.TranslationStore):
     @property
     def merge_on(self):
         """The matching criterion to use when merging on."""
-        return self.parseheader().get('X-Merge-On', 'id')
+        return self.parseheader().get("X-Merge-On", "id")
