@@ -138,7 +138,6 @@ from translate.misc import quote
 from translate.misc.multistring import multistring
 from translate.storage import base
 
-
 labelsuffixes = (".label", ".title")
 """Label suffixes: entries with this suffix are able to be comibed with accesskeys
 found in in entries ending with :attr:`.accesskeysuffixes`"""
@@ -483,7 +482,10 @@ class DialectGwt(DialectJavaUtf8):
 
     @classmethod
     def encode(cls, string, encoding=None):
-        result = super().encode(string, encoding)
+        if encoding not in ("utf-8", "utf-16"):
+            result = quote.javapropertiesencode(string or "")
+        else:
+            result = quote.java_utf8_properties_encode(string or "")
         return result.replace("'", "''")
 
     @classmethod
