@@ -31,33 +31,39 @@ from tempfile import NamedTemporaryFile
 
 from translate.storage import base
 
-
 try:
     from aeidon import Subtitle, documents, newlines
     from aeidon.encodings import detect
-    from aeidon.files import (AdvSubStationAlpha, MicroDVD, SubRip,
-                              SubStationAlpha, new)
+    from aeidon.files import AdvSubStationAlpha, MicroDVD, SubRip, SubStationAlpha, new
     from aeidon.util import detect_format as determine
 except ImportError:
     try:
         from gaupol import FormatDeterminer, documents
         from gaupol.encodings import detect
-        from gaupol.files import (AdvSubStationAlpha, MicroDVD, SubRip,
-                                  SubStationAlpha, new)
+        from gaupol.files import (
+            AdvSubStationAlpha,
+            MicroDVD,
+            SubRip,
+            SubStationAlpha,
+            new,
+        )
         from gaupol.newlines import newlines
         from gaupol.subtitle import Subtitle
+
         _determiner = FormatDeterminer()
         determine = _determiner.determine
     except ImportError:
-        raise ImportError('\naeidon or gaupol package required for Subtitle support')
+        raise ImportError("\naeidon or gaupol package required for Subtitle support")
 
 
 class SubtitleUnit(base.TranslationUnit):
     """A subtitle entry that is translatable"""
 
+    init_time = "00:00:00.000"
+
     def __init__(self, source=None, **kwargs):
-        self._start = "00:00:00.000"
-        self._end = "00:00:00.000"
+        self._start = self.init_time
+        self._end = self.init_time
         self._duration = 0.0
         if source:
             self.source = source
@@ -65,18 +71,24 @@ class SubtitleUnit(base.TranslationUnit):
         super().__init__(source)
 
     def getnotes(self, origin=None):
-        if origin in ['programmer', 'developer', 'source code', None]:
+        if origin in ["programmer", "developer", "source code", None]:
             return "visible for %d seconds" % self._duration
         else:
-            return ''
+            return ""
 
     def getlocations(self):
-        return ["%s-->%s" % (self._start, self._end)]
+        return [f"{self._start}-->{self._end}"]
 
     def getid(self):
         return self.getlocations()[0]
 
 
+class MicroDVDUnit(SubtitleUnit):
+    """MicroDVD unit, it uses frames instead of time as start/end."""
+
+    init_time = 0
+
+
 class SubtitleFile(base.TranslationStore):
     """A subtitle file"""
 
@@ -118,10 +130,10 @@ class SubtitleFile(base.TranslationStore):
             raise base.ParseError(e)
 
     def _parsefile(self, storefile):
-        if hasattr(storefile, 'name'):
+        if hasattr(storefile, "name"):
             self.filename = storefile.name
             storefile.close()
-        elif hasattr(storefile, 'filename'):
+        elif hasattr(storefile, "filename"):
             self.filename = storefile.filename
             storefile.close()
         elif isinstance(storefile, str):
@@ -142,17 +154,15 @@ class SubtitleFile(base.TranslationStore):
     def parse(self, input):
         if isinstance(input, bytes):
             # Gaupol does not allow parsing from strings
-            kwargs = {
-                'delete': False
-            }
+            kwargs = {"delete": False}
             if self.filename:
-                kwargs['suffix'] = self.filename
+                kwargs["suffix"] = self.filename
 
             temp_file = NamedTemporaryFile(**kwargs)
             temp_file.close()
 
             try:
-                with open(temp_file.name, 'wb') as fh:
+                with open(temp_file.name, "wb") as fh:
                     fh.write(input)
                 self._parsefile(temp_file.name)
             finally:
@@ -171,12 +181,12 @@ class SubRipFile(SubtitleFile):
     """specialized class for SubRipFile's only"""
 
     Name = "SubRip subtitles file"
-    Extensions = ['srt']
+    Extensions = ["srt"]
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         if self._subtitlefile is None:
-            self._subtitlefile = SubRip(self.filename or '', self.encoding)
+            self._subtitlefile = SubRip(self.filename or "", self.encoding)
         if self._subtitlefile.newline is None:
             self._subtitlefile.newline = newlines.UNIX
 
@@ -185,12 +195,13 @@ class MicroDVDFile(SubtitleFile):
     """specialized class for SubRipFile's only"""
 
     Name = "MicroDVD subtitles file"
-    Extensions = ['sub']
+    Extensions = ["sub"]
+    UnitClass = MicroDVDUnit
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         if self._subtitlefile is None:
-            self._subtitlefile = MicroDVD(self.filename or '', self.encoding)
+            self._subtitlefile = MicroDVD(self.filename or "", self.encoding)
         if self._subtitlefile.newline is None:
             self._subtitlefile.newline = newlines.UNIX
 
@@ -199,12 +210,12 @@ class AdvSubStationAlphaFile(SubtitleFile):
     """specialized class for SubRipFile's only"""
 
     Name = "Advanced Substation Alpha subtitles file"
-    Extensions = ['ass']
+    Extensions = ["ass"]
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         if self._subtitlefile is None:
-            self._subtitlefile = AdvSubStationAlpha(self.filename or '', self.encoding)
+            self._subtitlefile = AdvSubStationAlpha(self.filename or "", self.encoding)
         if self._subtitlefile.newline is None:
             self._subtitlefile.newline = newlines.UNIX
 
@@ -213,11 +224,11 @@ class SubStationAlphaFile(SubtitleFile):
     """specialized class for SubRipFile's only"""
 
     Name = "Substation Alpha subtitles file"
-    Extensions = ['ssa']
+    Extensions = ["ssa"]
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         if self._subtitlefile is None:
-            self._subtitlefile = SubStationAlpha(self.filename or '', self.encoding)
+            self._subtitlefile = SubStationAlpha(self.filename or "", self.encoding)
         if self._subtitlefile.newline is None:
             self._subtitlefile.newline = newlines.UNIX
