@@ -274,7 +274,7 @@ class TestAndroidResourceUnit(test_monolingual.TestMonolingualUnit):
 
     def test_parse_quoted_newlines(self):
         self.__check_parse(
-            "\n\nstring with newlines",
+            "\n\n\n\nstring with newlines",
             r"""<string name="teststring">"
 \n
 \nstring with newlines"</string>
@@ -469,6 +469,21 @@ class TestAndroidResourceUnit(test_monolingual.TestMonolingualUnit):
             self.__check_parse("", r'<string name="test">\utest</string>')
         self.__check_parse("\u0230", r'<string name="test">\u0230</string>')
 
+    def test_single_unescaped(self):
+        string = "a b c d"
+        xml = '<string name="teststring">a\nb\tc d</string>'
+        self.__check_parse(string, xml)
+
+    def test_single_escaped_alone(self):
+        string = "a\nb\tc d"
+        xml = '<string name="teststring">a"\n"b"\t"c" "d</string>'
+        self.__check_parse(string, xml)
+
+    def test_single_escaped_full(self):
+        string = "a\nb\tc d"
+        xml = '<string name="teststring">"a\nb\tc d"</string>'
+        self.__check_parse(string, xml)
+
 
 class TestAndroidResourceFile(test_monolingual.TestMonolingualStore):
     StoreClass = aresource.AndroidResourceFile
@@ -723,3 +738,101 @@ class TestAndroidResourceFile(test_monolingual.TestMonolingualStore):
         assert bytes(store) == content
         store.units[0].target = "Test <b>string</b> with  space"
         assert bytes(store).decode() == newcontent
+
+    def test_xliff_g(self):
+        template = """<?xml version="1.0" encoding="utf-8"?>
+<resources>
+</resources>"""
+        original = """<?xml version="1.0" encoding="utf-8"?>
+<resources>
+    <string name="id">Test: <xliff:g xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">%s</xliff:g></string>
+</resources>"""
+        expected = """<?xml version="1.0" encoding="utf-8"?>
+<resources>
+    <string name="id">Other: <xliff:g xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">%s</xliff:g></string>
+</resources>"""
+        origstore = self.StoreClass()
+        origstore.parse(original.encode())
+        store = self.StoreClass()
+        store.parse(template.encode())
+        store.addunit(origstore.units[0], new=True)
+        assert bytes(store).decode() == original
+        store.units[
+            0
+        ].target = """Other: <xliff:g xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">%s</xliff:g>"""
+        assert bytes(store).decode() == expected
+
+    def test_xliff_namespace(self):
+        original = """<?xml version="1.0" encoding="utf-8"?>
+<resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
+    <string name="id">Test</string>
+</resources>"""
+        expected = """<?xml version="1.0" encoding="utf-8"?>
+<resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
+    <string name="id">Test: <xliff:g>%s</xliff:g></string>
+</resources>"""
+        store = self.StoreClass()
+        store.parse(original.encode())
+        assert bytes(store).decode() == original
+        store.units[
+            0
+        ].target = """Test: <xliff:g xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">%s</xliff:g>"""
+        # The namespace should be flattened as it is defined in the toplevel element
+        assert bytes(store).decode() == expected
+
+    def test_edit_plural_zh_hk(self):
+        content = """<?xml version="1.0" encoding="utf-8"?>
+<resources>
+    <plurals name="vms_num_visitors">
+        <item quantity="one">%d visitor</item>
+        <item quantity="other">%d visitors</item>
+    </plurals>
+</resources>"""
+        store = self.StoreClass()
+        store.targetlanguage = "zh-rHK"
+        store.parse(content.encode())
+        store.units[0].target = "%d 訪客"
+        assert (
+            bytes(store).decode()
+            == """<?xml version="1.0" encoding="utf-8"?>
+<resources>
+    <plurals name="vms_num_visitors">
+        <item quantity="other">%d 訪客</item>
+    </plurals>
+</resources>"""
+        )
+
+    def test_edit_plural_b_zh_hk(self):
+        content = """<?xml version="1.0" encoding="utf-8"?>
+<resources>
+    <plurals name="vms_num_visitors">
+        <item quantity="one">%d visitor</item>
+        <item quantity="other">%d visitors</item>
+    </plurals>
+</resources>"""
+        store = self.StoreClass()
+        store.targetlanguage = "b+zh+Hant+HK"
+        store.parse(content.encode())
+        store.units[0].target = "%d 訪客"
+        assert (
+            bytes(store).decode()
+            == """<?xml version="1.0" encoding="utf-8"?>
+<resources>
+    <plurals name="vms_num_visitors">
+        <item quantity="other">%d 訪客</item>
+    </plurals>
+</resources>"""
+        )
+
+    def test_missing_plural(self):
+        content = """<?xml version="1.0" encoding="utf-8"?>
+<resources>
+    <plurals name="vms_num_visitors">
+        <item quantity="one">%d visitor</item>
+        <item quantity="other">%d visitors</item>
+    </plurals>
+</resources>"""
+        store = self.StoreClass()
+        store.targetlanguage = "fr"
+        store.parse(content.encode())
+        assert store.units[0].target == multistring(["%d visitor", "", "%d visitors"])
