@@ -6,7 +6,6 @@ from pytest import importorskip, mark, raises
 from translate.misc.multistring import multistring
 from translate.storage import test_po
 
-
 pytestmark = mark.skipif(
     not sys.platform.startswith("linux"), reason="cpo is only available on Linux"
 )
@@ -159,7 +158,7 @@ class TestCPOFile(test_po.TestPOFile):
 
     def test_output_str_unicode(self):
         """checks that we can serialize pofile, unit content is in unicode"""
-        posource = """#: nb\nmsgid "Norwegian Bokm\xe5l"\nmsgstr ""\n"""
+        posource = """#: nb\nmsgid "Norwegian Bokmål"\nmsgstr ""\n"""
         pofile = self.StoreClass(BytesIO(posource.encode("UTF-8")), encoding="UTF-8")
         assert len(pofile.units) == 1
         print(bytes(pofile))
