@@ -1,13 +1,14 @@
 from io import BytesIO
 
-from pytest import raises
+from pytest import mark, raises
 
 from translate.misc.multistring import multistring
 from translate.storage import pypo, test_po
 
 
 class TestHelpers:
-    def test_unescape(self):
+    @staticmethod
+    def test_unescape():
         assert pypo.unescape(r"koei") == "koei"
         assert pypo.unescape(r"koei\n") == "koei\n"
         assert pypo.unescape(r"koei\\") == "koei\\"
@@ -24,7 +25,8 @@ class TestHelpers:
         assert pypo.unescape(r"\"\\koei\"\\") == '"\\koei"\\'
         assert pypo.unescape(r"\\\rkoei\r\\") == "\\\rkoei\r\\"
 
-    def test_quoteforpo(self):
+    @staticmethod
+    def test_quoteforpo():
         """Special escaping routine to manage newlines and linewrap in PO"""
         # Simple case
         assert pypo.quoteforpo("Some test") == ['"Some test"']
@@ -70,7 +72,8 @@ class TestHelpers:
             '"obhucabhuca ukudibanisa kwakho.</b>"',
         ]
 
-    def test_quoteforpo_escaped_quotes(self):
+    @staticmethod
+    def test_quoteforpo_escaped_quotes():
         """Ensure that we don't break \" in two when wrapping
 
         See :issue:`3140`
@@ -586,3 +589,34 @@ This is just a random text file.
 """
         with raises(ValueError):
             self.poparse(posource)
+
+    def test_dos_newlines_write(self):
+        """checks that mixed newlines are properly parsed"""
+        posource = b"""msgid "test me"\r
+msgstr ""\r
+"""
+        poexpected = b"""#, fuzzy\r
+msgid "test me"\r
+msgstr ""\r
+"""
+        pofile = self.poparse(posource)
+        assert len(pofile.units) == 1
+        unit = pofile.units[0]
+        assert unit.source == "test me"
+        assert bytes(pofile) == posource
+        unit.markfuzzy(True)
+        assert bytes(pofile) == poexpected
+
+    @mark.xfail(reason="Not sure if this can not be parsed gracefully")
+    def test_mixed_newlines_typecomment(self):
+        """checks that mixed newlines in typecomments are properly parsed"""
+        # This was generated by translate-tookit prior to
+        # issue that test_dos_newlines_write is covering was fixed.
+        posource = b"""#, fuzzy
+msgid "test me"\r
+msgstr ""\r
+"""
+        pofile = self.poparse(posource)
+        assert len(pofile.units) == 1
+        assert pofile.units[0].source == "test me"
+        assert bytes(pofile) == posource
