@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2002-2006 Zuza Software Foundation
 #
@@ -18,22 +17,26 @@
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 #
 
-from translate.storage import factory
 from translate.storage.xml_extract import unit_tree
 
-
 # _split_xpath_component
 
 
 def test__split_xpath_component():
-    assert (u'some-tag', 0) == unit_tree._split_xpath_component(u'some-tag[0]')
+    assert ("some-tag", 0) == unit_tree._split_xpath_component("some-tag[0]")
+
 
 # _split_xpath
 
 
 def test__split_xpath():
-    assert [(u'p', 4), (u'text', 3), (u'body', 2), (u'document-content', 1)] == \
-        unit_tree._split_xpath(u'document-content[1]/body[2]/text[3]/p[4]')
+    assert [
+        ("p", 4),
+        ("text", 3),
+        ("body", 2),
+        ("document-content", 1),
+    ] == unit_tree._split_xpath("document-content[1]/body[2]/text[3]/p[4]")
+
 
 # _add_unit_to_tree
 
@@ -42,17 +45,17 @@ def make_tree_1(unit):
     root = unit_tree.XPathTree()
     node = root
 
-    node.children[u'document-content', 1] = unit_tree.XPathTree()
-    node = node.children[u'document-content', 1]
+    node.children["document-content", 1] = unit_tree.XPathTree()
+    node = node.children["document-content", 1]
 
-    node.children[u'body', 1] = unit_tree.XPathTree()
-    node = node.children[u'body', 1]
+    node.children["body", 1] = unit_tree.XPathTree()
+    node = node.children["body", 1]
 
-    node.children[u'text', 1] = unit_tree.XPathTree()
-    node = node.children[u'text', 1]
+    node.children["text", 1] = unit_tree.XPathTree()
+    node = node.children["text", 1]
 
-    node.children[u'p', 1] = unit_tree.XPathTree()
-    node = node.children[u'p', 1]
+    node.children["p", 1] = unit_tree.XPathTree()
+    node = node.children["p", 1]
 
     node.unit = unit
 
@@ -61,16 +64,16 @@ def make_tree_1(unit):
 
 def make_tree_2(unit_1, unit_2):
     root = make_tree_1(unit_1)
-    node = root.children[u'document-content', 1]
+    node = root.children["document-content", 1]
 
-    node.children[u'body', 2] = unit_tree.XPathTree()
-    node = node.children[u'body', 2]
+    node.children["body", 2] = unit_tree.XPathTree()
+    node = node.children["body", 2]
 
-    node.children[u'text', 3] = unit_tree.XPathTree()
-    node = node.children[u'text', 3]
+    node.children["text", 3] = unit_tree.XPathTree()
+    node = node.children["text", 3]
 
-    node.children[u'p', 4] = unit_tree.XPathTree()
-    node = node.children[u'p', 4]
+    node.children["p", 4] = unit_tree.XPathTree()
+    node = node.children["p", 4]
 
     node.unit = unit_2
 
@@ -79,29 +82,30 @@ def make_tree_2(unit_1, unit_2):
 
 def test__add_unit_to_tree():
     from translate.storage import xliff
+
     xliff_file = xliff.xlifffile
-#    xliff_file = factory.classes[u'xlf']()
+    #    xliff_file = factory.classes['xlf']()
 
     # Add the first unit
 
-    unit_1 = xliff_file.UnitClass(u'Hello')
-    xpath_1 = u'document-content[1]/body[1]/text[1]/p[1]'
+    unit_1 = xliff_file.UnitClass("Hello")
+    xpath_1 = "document-content[1]/body[1]/text[1]/p[1]"
 
     constructed_tree_1 = unit_tree.XPathTree()
-    unit_tree._add_unit_to_tree(constructed_tree_1,
-                                unit_tree._split_xpath(xpath_1),
-                                unit_1)
+    unit_tree._add_unit_to_tree(
+        constructed_tree_1, unit_tree._split_xpath(xpath_1), unit_1
+    )
     test_tree_1 = make_tree_1(unit_1)
     assert test_tree_1 == constructed_tree_1
 
     # Add another unit
 
-    unit_2 = xliff_file.UnitClass(u'World')
-    xpath_2 = u'document-content[1]/body[2]/text[3]/p[4]'
+    unit_2 = xliff_file.UnitClass("World")
+    xpath_2 = "document-content[1]/body[2]/text[3]/p[4]"
 
     constructed_tree_2 = make_tree_1(unit_1)
-    unit_tree._add_unit_to_tree(constructed_tree_2,
-                                unit_tree._split_xpath(xpath_2),
-                                unit_2)
+    unit_tree._add_unit_to_tree(
+        constructed_tree_2, unit_tree._split_xpath(xpath_2), unit_2
+    )
     test_tree_2 = make_tree_2(unit_1, unit_2)
     assert test_tree_2 == constructed_tree_2
